..
   Template for the html base rendering

   Modified from
   https://github.com/sphinx-doc/sphinx/tree/master/sphinx/ext/autosummary/templates/autosummary/base.rst

lbfgsb.extract\_hess\_inv\_diag
===============================

.. currentmodule:: lbfgsb

.. autofunction:: extract_hess_inv_diag